﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Diagnostics;

namespace TinyWebPad
{
    public partial class frmmain : Form
    {
        private mshtml.IHTMLDocument2 doc;
        private string TempFile = string.Empty;

        private void OpenUrl(string localname, string Argv)
        {
            Process p = new Process();
            //Filename to open
            p.StartInfo.FileName = localname;
            //Optionl arguments
            p.StartInfo.Arguments = Argv;

            try
            {
                //Start process
                p.Start();
            }
            catch { }
        }

        private string FixPath(string localname)
        {
            if (localname.EndsWith(@"\"))
            {
                return localname;
            }
            return localname + @"\";
        }

        private void SavePageSource(string localname)
        {
            mshtml.HTMLDocument objHtm = (mshtml.HTMLDocument)vWebEdit.Document.DomDocument;
            //Get page sourcecode
            string Src = objHtm.documentElement.innerHTML;

            //Try and save the file
            try
            {
                using (StreamWriter sw = new StreamWriter(localname))
                {
                    //Write html source to file
                    sw.Write(Src);
                    //Close the file
                    sw.Close();
                }
            }
            catch { }
        }

        private void InsertHtmlCode(string Source)
        {
            //Create html text range.
            mshtml.IHTMLTxtRange tr = (mshtml.IHTMLTxtRange)doc.selection.createRange();
            //Paste in the source html
            tr.pasteHTML(Source);
        }

        private string GetHexColor()
        {
            ColorDialog cd = new ColorDialog();

            if (cd.ShowDialog() == DialogResult.OK)
            {
                //Return html color
                return System.Drawing.ColorTranslator.ToHtml(cd.Color);
            }
            return string.Empty;
        }

        private void DoCommand(string command)
        {
            string cColor = string.Empty;
            HtmlDocument hDoc = vWebEdit.Document;

            switch (command)
            {
                case "Undo":
                    //Undo
                    hDoc.ExecCommand("undo", false, null);
                    break;
                case "Redo":
                    //Redo
                    hDoc.ExecCommand("redo", false, null);
                    break;
                case "Image":
                    //Insert image
                    hDoc.ExecCommand("InsertImage", true, null);
                    break;
                case "Link":
                    //Insert hyperlink
                    hDoc.ExecCommand("createlink", true, null);
                    break;
                case "IndentA":
                    //Indent
                    hDoc.ExecCommand("Indent", false, null);
                    break;
                case "IndentB":
                    //Out dent
                    hDoc.ExecCommand("Outdent", false, null);
                    break;
                case "ListA":
                    //Inset unordered list
                    hDoc.ExecCommand("InsertUnorderedList", false, null);
                    break;
                case "ListB":
                    //Insert ordered list
                    hDoc.ExecCommand("InsertOrderedList", false, null);
                    break;
                case "ALeft":
                    //Align left
                    hDoc.ExecCommand("JustifyLeft", false, null);
                    break;
                case "ACenter":
                    //Align center
                    hDoc.ExecCommand("JustifyCenter", false, null);
                    break;
                case "ARight":
                    //Align right
                    hDoc.ExecCommand("JustifyRight", false, null);
                    break;
                case "HLine":
                    //Insert line
                    hDoc.ExecCommand("InsertHorizontalRule", false, null);
                    break;
                case "DoOpen":
                    //Open new document
                    hDoc.ExecCommand("open", true, null);
                    break;
                case "DoSave":
                    //Save document
                    hDoc.ExecCommand("saveas", true, null);
                    break;
                case "DoFont":
                    //Set fontname
                    hDoc.ExecCommand("fontname", false, cboFonts.Text);
                    break;
                case "DoFontSize":
                    //Set fontsize
                    hDoc.ExecCommand("fontsize", false, cboSize.Text);
                    break;
                case "Bold":
                    //Set font style bold
                    hDoc.ExecCommand("bold", false, null);
                    break;
                case "Italic":
                    //Set font style italic
                    hDoc.ExecCommand("italic", false, null);
                    break;
                case "Underline":
                    //Set font style underline
                    hDoc.ExecCommand("underline", false, null);
                    break;
                case "TextColor":
                    //Get color from dialog
                    cColor = GetHexColor();
                    //Checkif color is empty
                    if (!string.IsNullOrEmpty(cColor))
                    {
                        //Set the forecolor
                        hDoc.ExecCommand("forecolor", false, cColor);
                    }

                    break;
                case "BackColor":
                    //Get color from dialog
                    cColor = GetHexColor();
                    //Checkif color is empty
                    if (!string.IsNullOrEmpty(cColor))
                    {
                        //Set the forecolor
                        hDoc.ExecCommand("backcolor", false, cColor);
                    }

                    break;
            }
        }

        private void NewPage()
        {
            //Just opens a new blank page
           vWebEdit.Navigate("about:blank");
        }

        public frmmain()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            cboFonts.Items.Add("<Fontname>");
            cboSize.Items.Add("<Size>");

            //Temp fileanme used for viewing and showing
            TempFile = Path.Combine(Application.StartupPath, "b34xyztmp.html");

            //Fill combobox with fontnames.
            foreach (FontFamily f in FontFamily.Families)
            {
                cboFonts.Items.Add(f.Name);
            }

            //Add font sizes
            for (int x = 1; x <= 7; x++)
            {
                cboSize.Items.Add(x);
            }

            //Add headings
            cboHeader.Items.Add("Heading1");
            cboHeader.Items.Add("Heading2");
            cboHeader.Items.Add("Heading3");
            cboHeader.Items.Add("Heading4");
            cboHeader.Items.Add("Heading5");
            cboHeader.Items.Add("Heading6");
            cboHeader.Items.Add("Paragraph");
            cboHeader.Items.Add("DIV");
   
            //Set index's
            cboFonts.SelectedIndex = 0;
            cboSize.SelectedIndex = 0;
            cboHeader.SelectedIndex = 6;

            //Start new page
            NewPage();
        }

        private void vWebEdit_DocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
        {
            //Create doc object
            doc = (mshtml.IHTMLDocument2)this.vWebEdit.Document.DomDocument;
            //Turn on editing
            doc.designMode = "On";
            //Set focus on web control
            vWebEdit.Focus();
        }

        private void cmdBold_Click(object sender, EventArgs e)
        {
            //Do bold
            DoCommand("Bold");
        }

        private void cmdItalic_Click(object sender, EventArgs e)
        {
            //Do italic
            DoCommand("Italic");
        }

        private void cmdUnderline_Click(object sender, EventArgs e)
        {
            //Do underline
            DoCommand("Underline");
        }

        private void cmdTextCol_Click(object sender, EventArgs e)
        {
            //Do text forecolor
            DoCommand("TextColor");
        }

        private void cmdBackCol_Click(object sender, EventArgs e)
        {
            //Do text backcolor
            DoCommand("BackColor");
        }

        private void cboFonts_SelectedIndexChanged(object sender, EventArgs e)
        {
            //Do font
            if (cboFonts.SelectedIndex != 0)
            {
                DoCommand("DoFont");
            }
        }

        private void cboSize_SelectedIndexChanged(object sender, EventArgs e)
        {
            //Do fontsize
            if (cboSize.SelectedIndex != 0)
            {
                DoCommand("DoFontSize");
            }
        }

        private void cmdBr_Click(object sender, EventArgs e)
        {
            //Insert line break
            InsertHtmlCode("<br>");
        }

        private void cmdSpace_Click(object sender, EventArgs e)
        {
            //Insert space
            InsertHtmlCode("&nbsp;");
        }

        private void cmdNew_Click(object sender, EventArgs e)
        {
            //Create new document
            NewPage();
        }

        private void cmdOpen_Click(object sender, EventArgs e)
        {
            //Open document
            DoCommand("DoOpen");
        }

        private void cmdSave_Click(object sender, EventArgs e)
        {
            //Save document
            DoCommand("DoSave");
        }

        private void cboHeader_SelectedIndexChanged(object sender, EventArgs e)
        {
            HtmlDocument hDoc = vWebEdit.Document;

            try
            {
                //Do headings
                switch (cboHeader.SelectedIndex)
                {
                    case 0:
                        hDoc.ExecCommand("FormatBlock", false, "<h1>");
                        break;
                    case 1:
                        hDoc.ExecCommand("FormatBlock", false, "<h2>");
                        break;
                    case 2:
                        hDoc.ExecCommand("FormatBlock", false, "<h3>");
                        break;
                    case 3:
                        hDoc.ExecCommand("FormatBlock", false, "<h4>");
                        break;
                    case 4:
                        hDoc.ExecCommand("FormatBlock", false, "<h5>");
                        break;
                    case 5:
                        hDoc.ExecCommand("FormatBlock", false, "<h6>");
                        break;
                    case 6:
                        hDoc.ExecCommand("FormatBlock", false, "<p>");
                        break;
                    case 7:
                        hDoc.ExecCommand("FormatBlock", false, "<div>");
                        break;
                }
            }
            catch { }
        }

        private void cmdLine_Click(object sender, EventArgs e)
        {
            //Inset Horizontal Line
            DoCommand("HLine");
        }

        private void cmdALeft_Click(object sender, EventArgs e)
        {
            //Align left
            DoCommand("ALeft");
        }

        private void cmdACenter_Click(object sender, EventArgs e)
        {
            //Align center
            DoCommand("ACenter");
        }

        private void cmdARight_Click(object sender, EventArgs e)
        {
            //Align right
            DoCommand("ARight");
        }

        private void cmdBullet_Click(object sender, EventArgs e)
        {
            //Inset unordered list
            DoCommand("ListA");
        }

        private void cmdDigit_Click(object sender, EventArgs e)
        {
            //Insert ordered list
            DoCommand("ListB");
        }

        private void cmdIndent_Click(object sender, EventArgs e)
        {
            //Indent
            DoCommand("IndentA");
        }

        private void cmdAOutDent_Click(object sender, EventArgs e)
        {
            //Outdent
            DoCommand("IndentB");
        }

        private void cmdLink_Click(object sender, EventArgs e)
        {
            //Inset hyperlink
            DoCommand("Link");
        }

        private void cmdImage_Click(object sender, EventArgs e)
        {
            //Inset image
            DoCommand("Image");
        }

        private void cmdUndo_Click(object sender, EventArgs e)
        {
            //Do undo
            DoCommand("Undo");
        }

        private void cmdRedo_Click(object sender, EventArgs e)
        {
            //Do redo
            DoCommand("Redo");
        }

        private void cmdCode_Click(object sender, EventArgs e)
        {
            //Save sourcecode
            SavePageSource(TempFile);
            //Do view source
            OpenUrl("notepad.exe", TempFile);
        }

        private void cmdPreview_Click(object sender, EventArgs e)
        {
            //Save sourcecode
            SavePageSource(TempFile);
            //View web page
            OpenUrl(TempFile, string.Empty);
        }

        private void cmdDateTime_Click(object sender, EventArgs e)
        {
            //Insert date and time
            InsertHtmlCode(DateTime.Now.ToString());
        }

        private void cmdAbout_Click(object sender, EventArgs e)
        {
            //Show about info
            MessageBox.Show(this.Text + " v1.0\n\tBy Ben Jones",
                "About", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void cmdExit_Click(object sender, EventArgs e)
        {
            //Close this program
            this.Close();
        }
    }
}
